@@ -5,7 +5,6 @@ import random
 import os
 import sys
 from matplotlib.figure import Figure
-from mpl_toolkits.mplot3d import Axes3D
 import matplotlib.colors as colors
 import matplotlib.pyplot as plt
 import pathlib
@@ -13,9 +12,9 @@ import warnings
 from decimal import Decimal
 from motus import funciones_auxiliares as fa
 from motus import regiones_preferidas as rp
-from motus import analisis_regresion_lineal as arl
-from motus.fisica_estadistica import histogramas as m_hist
+from motus.fisica_estadistica import histogramas as m_hist, analisis_regresion_lineal as arl
 from motus.fisica_estadistica import entropia_divergencia as m_ed
+from motus.graficador import cilindros
 
 warnings.filterwarnings("error")
 
@@ -145,8 +144,6 @@ class Experimento:
             print("self.consecuencias: ", self.consecuencias)
             print(np.where(self.consecuencias == 1)[0])
 
-            self.consecuencias_valores_1 = np.where(self.consecuencias == 1)[0]
-
         self.valor_intervalos_tiempo = arreglo_tiempo.iloc[1] - arreglo_tiempo.iloc[0]
 
         print("Procesar tiempo irregular: ", procesar_tiempo_archivo_irregular)
@@ -549,58 +546,7 @@ class Experimento:
                                        categoria="visitas_regiones_no_preferidas",
                                        datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
 
-    def calcula_alturas_volumenes_circulares_objetos_relevantes(self, tamanio=24, divisiones=2, tipo="cilindros"):
-        longitud_movimientos = len(self.posiciones_x)
-        valor_min_divivido = int(tamanio / divisiones)
-        radios_figuras = list(range(valor_min_divivido, tamanio + 1, valor_min_divivido))
-        cantidad_posiciones_volumen_1 = list(np.zeros(len(radios_figuras)))
-        cantidad_posiciones_volumen_2 = list(np.zeros(len(radios_figuras)))
-        cantidad_posiciones_volumen_3 = list(np.zeros(len(radios_figuras)))
-        cantidad_posiciones_volumen_4 = list(np.zeros(len(radios_figuras)))
 
-        for i in range(0, longitud_movimientos):
-            x_pos = self.posiciones_x[i]
-            y_pos = self.posiciones_y[i]
-            dist_1 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_1[0], x_pos, self.objeto_relevante_1[1],
-                                                       y_pos)
-            dist_2 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_2[0], x_pos, self.objeto_relevante_2[1],
-                                                       y_pos)
-            dist_3 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_3[0], x_pos, self.objeto_relevante_3[1],
-                                                       y_pos)
-            dist_4 = fa.calcula_distancia_entre_puntos(self.objeto_relevante_4[0], x_pos, self.objeto_relevante_4[1],
-                                                       y_pos)
-            if dist_1 < tamanio:
-                cantidad_posiciones_volumen_1 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_1,
-                                                                                  radios_figuras,
-                                                                                  dist_1,
-                                                                                  tipo=tipo)
-            if dist_2 < tamanio:
-                cantidad_posiciones_volumen_2 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_2,
-                                                                                  radios_figuras,
-                                                                                  tipo=tipo)
-            if dist_3 < tamanio:
-                cantidad_posiciones_volumen_3 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_3,
-                                                                                  radios_figuras,
-                                                                                  tipo=tipo)
-            if dist_4 < tamanio:
-                cantidad_posiciones_volumen_4 = fa.modificar_lista_para_cilindros(cantidad_posiciones_volumen_4,
-                                                                                  radios_figuras,
-                                                                                  tipo=tipo)
-
-        print("Cantidad de posiciones para volumen 1:")
-        print(cantidad_posiciones_volumen_1)
-        print("Cantidad de posiciones para volumen 2:")
-        print(cantidad_posiciones_volumen_2)
-        print("Cantidad de posiciones para volumen 3:")
-        print(cantidad_posiciones_volumen_3)
-        print("Cantidad de posiciones para volumen 4:")
-        print(cantidad_posiciones_volumen_4)
-
-        self.cantidad_posiciones_volumen_1 = cantidad_posiciones_volumen_1
-        self.cantidad_posiciones_volumen_2 = cantidad_posiciones_volumen_2
-        self.cantidad_posiciones_volumen_3 = cantidad_posiciones_volumen_3
-        self.cantidad_posiciones_volumen_4 = cantidad_posiciones_volumen_4
-        self.radios_volumenes = radios_figuras
 
     def obtener_indice_regiones_objeto(self):
         lista_objetos_relevantes = [self.objeto_relevante_1,
@@ -915,78 +861,55 @@ class Experimento:
         data = pd.DataFrame(data)
         data.to_csv(nombre, header=None, index=None)
 
-    def grafica(self, grafica, lim_inf_x=None, lim_sup_x=None, lim_inf_y=None, lim_sup_y=None,
-                tamanio_vectores=100, brinco_temporal=int(1), consencuencia_elegida=None,
-                tamanio_volumenes=24, div_volumenes=2, tipo_grafica_volumen="cilindros",
-                arreglo_series_tiempo=None, brincos_series_tiempo=1, longitud_series_tiempo=1,
-                arreglo_grafica_distancias=[True, True, True, True],
-                rotacion_grafica_3d=220):
-
+    def graficar_figura(self, nombre_grafica, config_grafica):
         print("-----------------------------------------------------------")
-        print("Tipo de gráfica", grafica)
+        print("Tipo de gráfica", nombre_grafica)
+
+        limites_x, limites_y = config_grafica.regresa_config_grafica_general()
+        lim_inf_x = limites_x[0]
+        lim_sup_x = limites_x[1]
+        lim_inf_y = limites_y[0]
+        lim_sup_y = limites_y[1]
+
+        objetos_seleccionados = config_grafica.regresa_config_grafica_distancias()
+        objeto_1_seleccionado = objetos_seleccionados[0]
+        objeto_2_seleccionado = objetos_seleccionados[1]
+        objeto_3_seleccionado = objetos_seleccionados[2]
+        objeto_4_seleccionado = objetos_seleccionados[3]
 
-        print("Valores de límites de gráfica:", lim_inf_x, lim_sup_x, lim_inf_y, lim_sup_y)
 
         fig = Figure(figsize=(6, 6))
         plt = fig.add_subplot(111)
         plt.grid(True)
 
-        if grafica is not 'region_cuadricula_3d':
-            if lim_inf_x is not None and lim_sup_x is not None:
-                plt.set_xlim(lim_inf_x, lim_sup_x)
-            if lim_inf_y is not None and lim_sup_y is not None:
-                plt.set_ylim(lim_inf_y, lim_sup_y)
+        if nombre_grafica is not 'region_cuadricula_3d':
+            if limites_x[0] is not None and limites_x[1] is not None:
+                plt.set_xlim(limites_x[0], limites_x[1])
+            if limites_y[0] is not None and limites_y[1] is not None:
+                plt.set_ylim(limites_y[0], limites_y[1])
 
-        if grafica == 'subrutas':
-            # print("----------------------------------------------------------------")
-            # print("Graficando subrutas: ")
-            lista_colores = ["blue", "red", "green", "orange", "purple", "cyan", "magenta", "brown", "pink", "gray"]
-            # print("Lista total de subsucesiones parecidas:", self.lista_indices_subsucesiones_parecidas)
-            for i in range(len(self.lista_indices_subsucesiones_parecidas)):
-                conjunto_subsucesiones_similares = self.lista_indices_subsucesiones_parecidas[i]
-                # print("Sucesiones parecidas: ", conjunto_subsucesiones_similares)
-                color = lista_colores[i]
-                """
-
-                """
-                punto_inicial = False
-                for subsucesion in conjunto_subsucesiones_similares:
-                    trazo_subsucesion_actual = self.lista_con_trazo_de_subsucesiones[subsucesion]
-                    if punto_inicial is False:
-                        plt.scatter(self.posiciones_x[trazo_subsucesion_actual[0]],
-                                    self.posiciones_y[trazo_subsucesion_actual[0]],
-                                    s=50, edgecolors="black", color=color)
-                        punto_inicial = True
-                    print("Subsucesion actual: ", subsucesion)
-                    print("List con trazo de subsucesiones: ", trazo_subsucesion_actual)
-                    """
-                    valores = list(
-                        range(self.modulo * indice_de_subsucesion, self.modulo * indice_de_subsucesion + self.modulo * self.tamanio))
-                    """
-                    plt.plot(self.posiciones_x[trazo_subsucesion_actual],
-                             self.posiciones_y[trazo_subsucesion_actual],
-                             color=color)
-            plt.set_xlim(0, self.dimension_caja[0])
-            plt.set_ylim(0, self.dimension_caja[1])
-
-        if grafica == 'ruta':
+        if nombre_grafica == 'ruta':
             print("Entro a ruta")
 
-            if (lim_inf_x is None) and (lim_sup_x is None):
-                plt.set_xlim(0, self.dimension_caja[0])
-            if (lim_inf_y is None) and (lim_sup_y is None):
-                plt.set_ylim(0, self.dimension_caja[1])
             plt.plot(self.posiciones_x, self.posiciones_y, color='blue')
-            plt.plot(self.objeto_relevante_1[0], self.objeto_relevante_1[1], '*', color='blue')
-            plt.plot(self.objeto_relevante_2[0], self.objeto_relevante_2[1], 'o', color='green')
-            plt.plot(self.objeto_relevante_3[0], self.objeto_relevante_3[1], 'o', color='red')
-            plt.plot(self.objeto_relevante_4[0], self.objeto_relevante_4[1], 'o', color='orange')
+            if objeto_1_seleccionado is True:
+                plt.plot(self.objeto_relevante_1[0], self.objeto_relevante_1[1], '*', color='blue')
+            if objeto_2_seleccionado is True:
+                plt.plot(self.objeto_relevante_2[0], self.objeto_relevante_2[1], 'o', color='green')
+            if objeto_3_seleccionado is True:
+                plt.plot(self.objeto_relevante_3[0], self.objeto_relevante_3[1], 'o', color='red')
+            if objeto_4_seleccionado is True:
+                plt.plot(self.objeto_relevante_4[0], self.objeto_relevante_4[1], 'o', color='orange')
 
-        if grafica == 'ruta_vectores':
+
+        elif nombre_grafica == 'ruta_vectoriales_consecuencia':
+
+            brinco_temporal, tamanio_vectores, consecuencia_elegida = \
+                config_grafica.regresa_config_grafica_consecuencias()
 
             print("Brinco temporal: ", brinco_temporal)
             print("Tamanio vectores: ", tamanio_vectores)
-            print("Consecuencia elegida:", consencuencia_elegida)
+            print("Consecuencia elegida:", consecuencia_elegida)
 
             x_pos_antes_consecuencia = self.posiciones_x.tolist()
             y_pos_antes_consecuencia = self.posiciones_y.tolist()
@@ -994,27 +917,27 @@ class Experimento:
             x_pos_despues_consecuencia = self.posiciones_x.tolist()
             y_pos_despues_consecuencia = self.posiciones_y.tolist()
 
-            x_pos_antes_consecuencia = x_pos_antes_consecuencia[int(consencuencia_elegida - tamanio_vectores):
-                                                                int(consencuencia_elegida):
+            x_pos_antes_consecuencia = x_pos_antes_consecuencia[int(consecuencia_elegida - tamanio_vectores):
+                                                                int(consecuencia_elegida):
                                                                 int(brinco_temporal)]
 
-            y_pos_antes_consecuencia = y_pos_antes_consecuencia[int(consencuencia_elegida - tamanio_vectores):
-                                                                int(consencuencia_elegida):
+            y_pos_antes_consecuencia = y_pos_antes_consecuencia[int(consecuencia_elegida - tamanio_vectores):
+                                                                int(consecuencia_elegida):
                                                                 int(brinco_temporal)]
 
             print("Tamanios iguales : ", len(x_pos_antes_consecuencia) == len(y_pos_antes_consecuencia))
 
-            x_pos_despues_consecuencia = x_pos_despues_consecuencia[int(consencuencia_elegida):
-                                                                    int(consencuencia_elegida + tamanio_vectores):
+            x_pos_despues_consecuencia = x_pos_despues_consecuencia[int(consecuencia_elegida):
+                                                                    int(consecuencia_elegida + tamanio_vectores):
                                                                     int(brinco_temporal)]
-            y_pos_despues_consecuencia = y_pos_despues_consecuencia[int(consencuencia_elegida):
-                                                                    int(consencuencia_elegida + tamanio_vectores):
+            y_pos_despues_consecuencia = y_pos_despues_consecuencia[int(consecuencia_elegida):
+                                                                    int(consecuencia_elegida + tamanio_vectores):
                                                                     int(brinco_temporal)]
 
             new_x_pos_antes = x_pos_antes_consecuencia.copy()
-            new_x_pos_antes.append(self.posiciones_x[consencuencia_elegida])
+            new_x_pos_antes.append(self.posiciones_x[consecuencia_elegida])
             new_y_pos_antes = y_pos_antes_consecuencia.copy()
-            new_y_pos_antes.append(self.posiciones_y[consencuencia_elegida])
+            new_y_pos_antes.append(self.posiciones_y[consecuencia_elegida])
 
             x_direct_antes, y_direct_antes = fa.obtener_vectores_posicion_flechas(new_x_pos_antes,
                                                                                   new_y_pos_antes)
@@ -1045,32 +968,32 @@ class Experimento:
             plt.set_xlim(0, self.dimension_caja[0])
             plt.set_ylim(0, self.dimension_caja[1])
 
-        elif grafica == 'distancias':
+        elif nombre_grafica == 'distancias':
             print("Entro a distancias")
             lista_valores_minimos = []
             lista_valores_maximos = []
-            if arreglo_grafica_distancias[0] is True:
+            if objeto_1_seleccionado is True:
                 print(1)
                 print(self.dist_objeto_1)
                 print(self.dist_objeto_1.max())
                 plt.plot(self.tiempo, self.dist_objeto_1, color='blue', label='Objeto 1')
                 lista_valores_minimos.append(self.dist_objeto_1.min())
                 lista_valores_maximos.append(self.dist_objeto_1.max())
-            if arreglo_grafica_distancias[1] is True:
+            if objeto_2_seleccionado is True:
                 print(2)
                 print(self.dist_objeto_2)
                 print(self.dist_objeto_2.max())
                 plt.plot(self.tiempo, self.dist_objeto_2, color='green', label='Objeto 2')
                 lista_valores_minimos.append(self.dist_objeto_2.min())
                 lista_valores_maximos.append(self.dist_objeto_2.max())
-            if arreglo_grafica_distancias[2] is True:
+            if objeto_3_seleccionado is True:
                 print(3)
                 print(self.dist_objeto_3)
                 print(self.dist_objeto_3.max())
                 plt.plot(self.tiempo, self.dist_objeto_3, color='red', label='Objeto 3')
                 lista_valores_minimos.append(self.dist_objeto_3.min())
                 lista_valores_maximos.append(self.dist_objeto_3.max())
-            if arreglo_grafica_distancias[3] is True:
+            if objeto_4_seleccionado is True:
                 print(4)
                 print(self.dist_objeto_4)
                 print(self.dist_objeto_4.max())
@@ -1085,7 +1008,7 @@ class Experimento:
 
             # plt.legend()
 
-        elif grafica == 'dist_prom':
+        elif nombre_grafica == 'dist_prom':
             print("Entro a distancia promediada a objeto")
 
             if lim_inf_y is None and lim_sup_y is None:
@@ -1097,7 +1020,7 @@ class Experimento:
 
             # plt.legend()
 
-        elif grafica == 'dist_min':
+        elif nombre_grafica == 'dist_min':
 
             print("Entro a dist_min")
 
@@ -1108,30 +1031,28 @@ class Experimento:
             plt.plot(self.tiempo, self.distancia_minima_objetos_2_3_4, color='red', label='Resto de objetos')
             plt.plot(self.tiempo, self.dist_objeto_1, color='blue', label='Objeto 1')
 
-            # plt.legend()
-
-        elif grafica == 'vel':
+        elif nombre_grafica == 'vel':
 
             print("Entro a vel")
             plt.scatter(self.tiempo, self.serie_velocidad, s=1)
 
-        elif grafica == 'vel_prom':
+        elif nombre_grafica == 'vel_prom':
             print("Entro a vel_prom")
             longitud_serie_velocidad_promediada = len(self.serie_velocidad_promediada)
             tiempo = np.linspace(0, longitud_serie_velocidad_promediada, longitud_serie_velocidad_promediada)
             plt.scatter(tiempo, self.serie_velocidad_promediada, s=1)
 
-        elif grafica == 'vel_hist':
+        elif nombre_grafica == 'vel_hist':
             print("Entro a vel_hist")
             print(plt.hist(self.serie_velocidad))
             plt.hist(self.serie_velocidad)
 
-        elif grafica == 'acel':
+        elif nombre_grafica == 'acel':
 
             print("Entro a acel")
             plt.scatter(self.tiempo, self.serie_aceleracion, s=1)
 
-        elif grafica == 'acel_prom':
+        elif nombre_grafica == 'acel_prom':
 
             # Se hace el cálculo de la velocidad en cada momento del tiempo
             # v_{t-1} = [((x_i - x_{i-1})^2 + (y_i - y_{i-1})^2)^(1/2)]/0.2
@@ -1184,12 +1105,12 @@ class Experimento:
         #    plt.imshow(self.matrizRec, cmap='gray', interpolation='nearest', vmin=0, vmax=5)
         #    plt.legend()
 
-        elif grafica == 'matriz_recurrencia_cuadriculada':
+        elif nombre_grafica == 'matriz_recurrencia_cuadriculada':
             plt.grid(False)
             plt.imshow(-1 * self.matriz_recurrencia_region_cuadriculada, origin='lower', cmap='gray',
                        interpolation='nearest', vmin=-1, vmax=0)
 
-        elif grafica == 'matriz_recurrencia_cuadriculada_objeto_1':
+        elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_1':
 
             plt.grid(False)
             plt.imshow(-1 * self.matriz_recurrencia_region_cuadriculada, origin='lower', cmap='gray',
@@ -1197,22 +1118,22 @@ class Experimento:
             plt.imshow(-1 * self.matriz_recurrencia_objeto_1, origin='lower', cmap='gray',
                        interpolation='nearest', vmin=-1, vmax=0)
 
-        elif grafica == 'matriz_recurrencia_cuadriculada_objeto_2':
+        elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_2':
             plt.grid(False)
             plt.imshow(-1 * self.matriz_recurrencia_objeto_2, origin='lower', cmap='gray',
                        interpolation='nearest')
 
-        elif grafica == 'matriz_recurrencia_cuadriculada_objeto_3':
+        elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_3':
             plt.grid(False)
             plt.imshow(-1 * self.matriz_recurrencia_objeto_3, origin='lower', cmap='gray',
                        interpolation='nearest')
 
-        elif grafica == 'matriz_recurrencia_cuadriculada_objeto_4':
+        elif nombre_grafica == 'matriz_recurrencia_cuadriculada_objeto_4':
             plt.grid(False)
             plt.imshow(-1 * self.matriz_recurrencia_objeto_4, origin='lower', cmap='gray',
                        interpolation='nearest')
 
-        elif grafica == 'matriz_recurrencia_cuadriculada_combinada':
+        elif nombre_grafica == 'matriz_recurrencia_cuadriculada_combinada':
             plt.grid(False)
             nueva_matriz_recurrencia_combinada = self.matriz_recurrencia_combinada + self.matriz_recurrencia_region_cuadriculada
             cmap = colors.ListedColormap(['white', 'black', 'blue', 'red', 'green', 'orange'])
@@ -1234,27 +1155,40 @@ class Experimento:
         #    plt.grid(False)
         #    plt.colorbar(
         #        plt.imshow(np.flipud(self.matriz_cuadriculada)))
-        elif grafica == 'regresion_lineal':
+
+        elif nombre_grafica == 'regresion_lineal':
+
             print("Entro a regresión lineal")
 
-            indices_tiempo, series_tiempo = arl.generar_series_tiempo(lista_a_procesar= arreglo_series_tiempo,
-                                                                     brinco_temporal=brincos_series_tiempo,
-                                                                     longitud_ventana_tiempo=longitud_series_tiempo)
+            tipo_regresion_lineal, brinco_temporal, longitud_serie_tiempo = config_grafica.regresa_config_grafica_regresion_lineal()
+
+            if tipo_regresion_lineal is "Velocidad":
+                arreglo_series_tiempo = np.array(self.serie_velocidad)
+            elif tipo_regresion_lineal is "Aceleración":
+                arreglo_series_tiempo = np.array(self.serie_aceleracion)
+
+            indices_tiempo, series_tiempo = arl.generar_series_tiempo(lista_a_procesar=arreglo_series_tiempo,
+                                                                      brinco_temporal=brinco_temporal,
+                                                                      longitud_ventana_tiempo=longitud_serie_tiempo)
 
             resultados = arl.generar_regresion_lineal_para_series_tiempo(indices_tiempo=indices_tiempo,
-                                                                        series_tiempo=series_tiempo)
+                                                                         series_tiempo=series_tiempo)
 
             for indice in range(0, len(indices_tiempo)):
-                plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue',  s=1)
+                plt.scatter(indices_tiempo[indice], series_tiempo[indice], color='blue', s=1)
                 plt.plot(indices_tiempo[indice], resultados[indice], color='red')
 
-        elif grafica == 'cilindros_objetos_importantes':
+        elif nombre_grafica == 'cilindros_objetos_importantes':
             print("Entro a volumenes_objetos_importantes")
 
-            self.calcula_alturas_volumenes_circulares_objetos_relevantes(tamanio=tamanio_volumenes,
-                                                                         divisiones=div_volumenes,
-                                                                         tipo=tipo_grafica_volumen)
-            rot_grafica_3d = rotacion_grafica_3d
+            tamanio_volumenes, div_volumenes, tipo_grafica_volumen, rot_grafica_3d = config_grafica.regresa_config_grafica_figuras()
+
+            cilindros.calcula_alturas_volumenes_circulares_objetos_relevantes(posiciones_x=self.posiciones_x,
+                                                                              posiciones_y=self.posiciones_y,
+                                                                              lista_objetos_relevantes=objetos_seleccionados,
+                                                                              tamanio=tamanio_volumenes,
+                                                                              divisiones=div_volumenes,
+                                                                              tipo=tipo_grafica_volumen)
 
             if getattr(sys, 'frozen', False):
                 os.environ['BASEMAPDATA'] = os.path.join(os.path.dirname(sys.executable), 'mplot3d')
@@ -1263,25 +1197,25 @@ class Experimento:
             ax.view_init(azim=rot_grafica_3d % 360, elev=0)
 
             for i in range(0, len(self.cantidad_posiciones_volumen_1)):
-                if arreglo_grafica_distancias[0] is True:
+                if objeto_1_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_1[0],
                                        self.objeto_relevante_1[1],
                                        self.radios_volumenes[i],
                                        self.cantidad_posiciones_volumen_1[i],
                                        ax)
-                if arreglo_grafica_distancias[1] is True:
+                if objeto_2_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_2[0],
                                        self.objeto_relevante_2[1],
                                        self.radios_volumenes[i],
                                        self.cantidad_posiciones_volumen_2[i],
                                        ax)
-                if arreglo_grafica_distancias[2] is True:
+                if objeto_3_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_3[0],
                                        self.objeto_relevante_3[1],
                                        self.radios_volumenes[i],
                                        self.cantidad_posiciones_volumen_3[i],
                                        ax)
-                if arreglo_grafica_distancias[3] is True:
+                if objeto_4_seleccionado is True:
                     fa.pintar_cilindro(self.objeto_relevante_4[0],
                                        self.objeto_relevante_4[1],
                                        self.radios_volumenes[i],
@@ -1310,11 +1244,11 @@ class Experimento:
 
             ax.view_init(azim=rot_grafica_3d)
 
-        elif grafica == 'region_cuadricula_3d':
+        elif nombre_grafica == 'region_cuadricula_3d':
 
             print("Entro a regionCuadricula3d")
 
-            rot_grafica_3d = rotacion_grafica_3d
+            rot_grafica_3d = 220
 
             objeto_1_x = self.objeto_relevante_1[0]
             objeto_1_y = self.objeto_relevante_1[1]
@@ -1394,11 +1328,11 @@ class Experimento:
 
             ax.view_init(azim=rot_grafica_3d)
 
-        elif grafica == 'region_cuadricula_3d_regiones_preferidas':
+        elif nombre_grafica == 'region_cuadricula_3d_regiones_preferidas':
 
             print("Entro a regionCuadricula3d, regiones preferidas")
 
-            rot_grafica_3d = rotacion_grafica_3d
+            rot_grafica_3d = 220
 
             objeto_1_x = self.objeto_relevante_1[0]
             objeto_1_y = self.objeto_relevante_1[1]
@@ -1478,11 +1412,11 @@ class Experimento:
 
             ax.view_init(azim=rot_grafica_3d)
 
-        elif grafica == 'region_cuadricula_3d_solo_regiones_preferidas':
+        elif nombre_grafica == 'region_cuadricula_3d_solo_regiones_preferidas':
 
             print("Entro a regionCuadricula3d, solo regiones preferidas")
 
-            rot_grafica_3d = rotacion_grafica_3d
+            rot_grafica_3d = 220
 
             objeto_1_x = self.objeto_relevante_1[0]
             objeto_1_y = self.objeto_relevante_1[1]
@@ -1562,11 +1496,11 @@ class Experimento:
 
             ax.view_init(azim=rot_grafica_3d)
 
-        elif grafica == 'region_cuadricula_3d_solo_regiones_no_preferidas':
+        elif nombre_grafica == 'region_cuadricula_3d_solo_regiones_no_preferidas':
 
             print("Entro a regionCuadricula3d, solo regiones no preferidas")
 
-            rot_grafica_3d = rotacion_grafica_3d
+            rot_grafica_3d = 220
 
             objeto_1_x = self.objeto_relevante_1[0]
             objeto_1_y = self.objeto_relevante_1[1]
